@@ -388,13 +388,13 @@ transform_date_timestamp <- function(DT) {
   check_argument(timezone, "character")
 
   from_timestamp <- c(
-    "^[0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}Z$",
-    "^[0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}\\.[0-9]+Z$",
+    # "^[0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}Z$",
+    "^[0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}\\.?[0-9]*Z$",
     "^[0-9]{4}-[0-9]{2}-[0-9]{2}[[:blank:]]+[0-9]{2}:[0-9]{2}:[0-9]{2}$"
   )
 
   to_timestamp <- c(
-    "%Y-%m-%dT%H:%M:%SZ",
+    # "%Y-%m-%dT%H:%M:%SZ",
     "%Y-%m-%dT%H:%M:%OSZ",
     "%Y-%m-%d %H:%M:%S"
   )
